<?php

require_once 'env.php';

function connect() {
  $host = DB_HOST;
  $db   = DB_NAME;
  $user = DB_USER;
  $pass = DB_PASS;

  $dsn = "mysql:host=$host;dbname=$db;charset=utf8mb4";

  try {
    $dbh = new PDO($dsn, $user, $pass, [
      PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
      PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC
    ]);
    return $dbh;
  } catch(PDOException $e) {
    echo '接続失敗です！' . $e->getMessage();
    exit();
  }
}

function bbsPost($onebbs) {
global $date, $name;
  $sql = 'INSERT INTO
          onebbs (name, comment, date)
        VALUES
          (:name, :comment, :date)';

  $dbh = connect();
  $dbh->beginTransaction();
  try {
    $stmt = $dbh->prepare($sql);
    $stmt->bindValue(':name', $name, PDO::PARAM_STR);
    $stmt->bindValue(':comment', $onebbs['comment'], PDO::PARAM_STR);
    $stmt->bindValue(':date', $date, PDO::PARAM_STR);
    $stmt->execute();
    $dbh->commit();
  } catch(PDOException $e) {
    $dbh->rollBack();
    exit($e);
  }
}

function getData($skip, $lines) {
  $dbh = connect();
  //①SQLの準備
  $sql = 'SELECT * FROM onebbs order by id DESC LIMIT :skip, :lines';
  $stmt = $dbh->prepare($sql);
  $stmt->bindValue(':skip', (int)$skip, PDO::PARAM_INT);
  $stmt->bindValue(':lines', (int)$lines, PDO::PARAM_INT);
  //②SQLの実行
  $stmt->execute();
  //③SQLの結果を受け取る
  $result = $stmt->fetchall();
  return $result;
  $dbh = null;
}

function lineCount() {
  $dbh = connect();
  $sql = 'SELECT * FROM onebbs';
  $stmt = $dbh -> query($sql);
  $count = $stmt -> rowCount();
  return $count;
}

/**
 * XSS対策：エスケープ処理
 *
 * @param string $s 対象の文字列
 * @return string 処理された文字列
 */
function h($s) {
  return htmlspecialchars($s, ENT_QUOTES, 'UTF-8');
}

/**
 * CSRF対策
 * @param void
 * @return string $csrf_token
 */
function setToken() {
  $csrf_token = bin2hex(random_bytes(32));
  $_SESSION['csrf_token'] = $csrf_token;

  return $csrf_token;
}

/**
 * コメントのURLにリンクを付ける（エスケープ処理も含む）
 * @param string $text 対象の文字列
 * @return string $text　処理された文字列
 */
function urlText($text) {
  $text    = htmlspecialchars($text, ENT_QUOTES, 'UTF-8');
  $pattern = '/((?:https?|ftp):\/\/[-_.!~*\'()a-zA-Z0-9;\/?:@&=+$,%#]+)/';
  $replace = '<a href="$1" target="_blank" rel="noopener noreferrer">$1</a>';
  $text    = preg_replace( $pattern, $replace, $text );
  return $text;
}
